@@ -2,10 +2,12 @@ import asyncio
 import logging
 
 from time import time
+
 from .. import bhf_signals
 from contextlib import suppress
 from inspect import isawaitable
 from ipaddress import ip_address
+from bhfutils.crawler.playwright.stealth import stealth_async
 from typing import Callable, Dict, Generator, Optional, Tuple, Type, TypeVar
 
 from playwright.async_api import (
@@ -16,7 +18,6 @@ from playwright.async_api import (
     Response as PlaywrightResponse,
     Route,
 )
-from playwright_stealth import stealth_async
 from scrapy import Spider, signals
 from scrapy.crawler import Crawler
 from scrapy.http import Request, Response
@@ -144,6 +145,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         logger.debug("Browser context started: '%s'", name)
         self.stats.inc_value("playwright/context_count")
         if self.default_navigation_timeout is not None:
+            context.set_default_timeout(self.default_navigation_timeout)
             context.set_default_navigation_timeout(self.default_navigation_timeout)
         return context
 
@@ -181,6 +183,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             self._get_total_page_count(),
         )
         if self.default_navigation_timeout is not None:
+            page.set_default_timeout(self.default_navigation_timeout)
             page.set_default_navigation_timeout(self.default_navigation_timeout)
 
         page.on("request", _make_request_logger("default"))
@@ -257,10 +260,8 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         finally:
             try:
                 if page is not None and not page.is_closed():
-                    logger.info(f"[{request.url}] Close page")
                     try:
                         await asyncio.wait_for(page.close(), timeout=10)
-                        logger.info(f"[{request.url}] Page closed")
                     except asyncio.TimeoutError:
                         if self.context_semaphores['default'].locked():
                             self.context_semaphores['default'].release()
@@ -272,12 +273,12 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
                     if self.context_semaphores['default'].locked():
                         self.context_semaphores['default'].release()
             except:
-                logger.error(f"[{request.url}] Error on page close")
+                logger.exception(f"[{request.url}] Error on page close")
                 raise
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
-        response = await page.goto(request.url, timeout=60000.0, wait_until=self.page_load_until)
+        response = await page.goto(request.url, wait_until=self.page_load_until)
 
         logger.info(f"[{request.url}] After goto")
         await self._apply_page_methods(page, request)
@@ -360,7 +361,6 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     def _make_close_page_callback(self, context_name: str) -> Callable:
         def close_page_callback() -> None:
-            logger.info("Close page callback")
             if context_name in self.context_semaphores and self.context_semaphores[context_name].locked():
                 self.context_semaphores[context_name].release()
 
